@@ -31,6 +31,7 @@
 #include "dbus/gkd-dbus.h"
 
 #include "egg/egg-cleanup.h"
+#include "egg/egg-error.h"
 #include "egg/egg-libgcrypt.h"
 #include "egg/egg-secure-memory.h"
 #include "egg/egg-unix-credentials.h"
@@ -122,7 +123,7 @@ parse_arguments (int *argc, char** argv[])
 	g_option_context_add_main_entries (context, option_entries, GETTEXT_PACKAGE);
 
 	if (!g_option_context_parse (context, argc, argv, &err)) {
-		g_printerr ("gnome-keyring-daemon: %s", err && err->message ? err->message : "");
+		g_printerr ("gnome-keyring-daemon: %s", egg_error_message (err));
 		g_clear_error (&err);
 	}
 
@@ -159,16 +160,18 @@ static gboolean do_warning = TRUE;
  * locking for memory between threads
  */
 
+G_LOCK_DEFINE_STATIC (memory_mutex);
+
 void
 egg_memory_lock (void)
 {
-	/* The daemon uses cooperative threading, and doesn't need locking */
+	G_LOCK (memory_mutex);
 }
 
 void
 egg_memory_unlock (void)
 {
-	/* The daemon uses cooperative threading, and doesn't need locking */
+	G_UNLOCK (memory_mutex);
 }
 
 void*
@@ -395,7 +398,7 @@ read_login_password (int fd)
 	/*
 	 * When --login is specified then the login password is passed
 	 * in on stdin. All data (including newlines) are part of the
-	 * password.
+	 * password. A zero length password is no password.
 	 */
 
 	gchar *buf = egg_secure_alloc (MAX_BLOCK);
@@ -411,17 +414,15 @@ read_login_password (int fd)
 			egg_secure_free (buf);
 			return NULL;
 
-		} else  {
-			char *n = egg_secure_realloc (ret, len + r + 1);
-			memset(n + len, 0, r + 1);
-			ret = n;
-			len = len + r;
+		} else if (r == 0 || len > MAX_LENGTH) {
+			break;
 
+		} else {
+			ret = egg_secure_realloc (ret, len + r + 1);
+			memset (ret + len, 0, r + 1);
+			len = len + r;
 			strncat (ret, buf, r);
 		}
-
-		if (r == 0 || len > MAX_LENGTH)
-			break;
 	}
 
 	egg_secure_free (buf);
