@@ -110,7 +110,7 @@ static void
 gcr_import_dialog_real_realize (GtkWidget *base)
 {
 	GcrImportDialog *self = GCR_IMPORT_DIALOG (base);
-	if (GTK_WIDGET_VISIBLE (self->pv->combo)) 
+	if (gtk_widget_get_visible (GTK_WIDGET (self->pv->combo)))
 		populate_slots (self);	
 	GTK_WIDGET_CLASS (_gcr_import_dialog_parent_class)->realize (base);
 }
@@ -131,7 +131,7 @@ gcr_import_dialog_constructor (GType type, guint n_props, GObjectConstructParam
 	/* Fill in the dialog from builder */
 	widget = GTK_WIDGET (gtk_builder_get_object (self->pv->builder, "import-dialog"));
 	g_return_val_if_fail (widget, FALSE);
-	gtk_container_add (GTK_CONTAINER (GTK_DIALOG (self)->vbox), widget);
+	gtk_container_add (GTK_CONTAINER (gtk_dialog_get_content_area (GTK_DIALOG (self))), widget);
 
 	/* Add a secure entry */
 	buffer = egg_entry_buffer_new ();
@@ -311,7 +311,7 @@ _gcr_import_dialog_get_selected_slot (GcrImportDialog *self)
 	
 	g_return_val_if_fail (GCR_IMPORT_DIALOG (self), NULL);
 	
-	if (GTK_WIDGET_VISIBLE (self->pv->combo))
+	if (gtk_widget_get_visible (GTK_WIDGET (self->pv->combo)))
 		populate_slots (self);
 	else
 		return NULL;
@@ -336,8 +336,8 @@ _gcr_import_dialog_set_selected_slot (GcrImportDialog *self, GP11Slot *slot)
 	gboolean matched;
 
 	g_return_if_fail (GCR_IMPORT_DIALOG (self));
-	
-	if (GTK_WIDGET_VISIBLE (self->pv->combo)) 
+
+	if (gtk_widget_get_visible (GTK_WIDGET (self->pv->combo)))
 		populate_slots (self);
 	else
 		g_return_if_reached ();
