@@ -83,7 +83,8 @@ factory_create_private_key (GckSession *session, GckTransaction *transaction,
 
 	gck_sexp_unref (sexp);
 
-	gck_session_complete_object_creation (session, transaction, GCK_OBJECT (key), attrs, n_attrs);
+	gck_session_complete_object_creation (session, transaction, GCK_OBJECT (key),
+	                                      TRUE, attrs, n_attrs);
 	return GCK_OBJECT (key);
 }
 
