@@ -35,6 +35,7 @@
 
 #include "gtest-helpers.h"
 
+#include "egg/egg-error.h"
 #include "egg/egg-secure-memory.h"
 
 #include "pkcs11/pkcs11.h"
@@ -150,7 +151,7 @@ test_data_read (const gchar *basename, gsize *n_result)
 	file = test_data_filename (basename);
 	if (!g_file_get_contents (file, &result, n_result, &error)) {
 		g_warning ("could not read test data file: %s: %s", file,
-		           error && error->message ? error->message : "");
+		           egg_error_message (error));
 		g_assert_not_reached ();
 	}
 
@@ -250,9 +251,7 @@ main (int argc, char* argv[])
 	g_thread_init (NULL);
 
 	test_path = getenv ("GNOME_KEYRING_TEST_PATH");
-	if (test_path) {
-		setenv ("GNOME_KEYRING_OUTSIDE_TEST", "TRUE", 1);
-	} else {
+	if (!test_path) {
 		test_path = "/tmp/test-gnome-keyring";
 		setenv ("GNOME_KEYRING_TEST_PATH", test_path, 1);
 		g_mkdir_with_parents (test_path, 0777);
